HiveCryptoAdapter class

Hive数据库加密适配器

Constructors

HiveCryptoAdapter({required String userId, required String deviceId, String? additionalEntropy})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decryptField(String encryptedValue) String
解密单个字段
encryptField(String value) String
加密单个字段
getHiveEncryptionKey() List<int>
获取Hive加密密钥(32字节)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited