DeviceIdentifier class

Constructors

DeviceIdentifier()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getDeviceId() Future<String>
获取设备唯一标识符
getInstallTimestamp() String
获取应用安装时间戳(首次运行时保存)