JsonUtils class

Constructors

JsonUtils()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dynamicToJson<T>({required dynamic json, required T defValue}) → T
jsonToObj<T>({required dynamic json, required T handleJson(Map<String, dynamic> map), required T defValue}) → T
json转对象
jsonToObjAsync<T>({required dynamic json, required T handleJson(Map<String, dynamic> map)}) Future<T>
大数据json转对象
jsonToObjList<T>({required dynamic json, required T handleJson(Map<String, dynamic> obj)}) List<T>
jsonToObjListAsync<T>({required dynamic json, required T handleJson(dynamic obj)}) Future<List<T>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited