LexoDataScale enum

数据量级配置枚举

Inheritance
Available extensions

Values

hundredThousand → const LexoDataScale

十万级别

const LexoDataScale(100000, "hundred_thousand")
million → const LexoDataScale

百万级别

const LexoDataScale(1000000, "million")
tenMillion → const LexoDataScale

千万级别

const LexoDataScale(10000000, "ten_million")
hundredMillion → const LexoDataScale

一亿级别

const LexoDataScale(100000000, "hundred_million")

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LexoDataScale>
A constant List of the values in this enum, in order of their declaration.