StorageConfig class

Constructors

StorageConfig({StorageType type = StorageType.sharedPreferences, bool enableEncryption = false, String? userId, String? deviceId, String? hiveBoxName = 'default_box'})
const

Properties

deviceId String?
final
enableEncryption bool
final
hashCode int
The hash code for this object.
no setterinherited
hiveBoxName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type StorageType
final
userId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited