StorageUtil class

Properties

hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
isNotEmpty bool
no setter
length int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() Future<bool>
close() Future<void>
containsKey(String key) Future<bool>
containsKeySync(String key) bool
getAll(List<String> keys) Map<String, dynamic>
getBoolean(String key, {bool defaultValue = false}) bool
getDouble(String key, {double defaultValue = 0.0}) double
getInt(String key, {int defaultValue = 0}) int
getJson(String key, {dynamic defaultValue = const {}}) → dynamic
getKeys() Set<String>
getMap(String key, {Map<String, dynamic> defaultValue = const {}}) Map<String, dynamic>
getObject<T>(String key, {required T defaultValue}) → T
getString(String key, {String defaultValue = ''}) String
getStringList(String key, {List<String> defaultValue = const []}) List<String>
migrateFromHiveToSP() Future<void>
migrateFromSPToHive() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putAll(Map<String, dynamic> values) Future<void>
putBoolean(String key, bool value) Future<bool>
putDouble(String key, double value) Future<bool>
putInt(String key, int value) Future<bool>
putJson(String key, dynamic value) Future<bool>
putMap(String key, Map<String, dynamic> value) Future<bool>
putObject<T>(String key, T value) Future<bool>
putString(String key, String value) Future<bool>
putStringList(String key, List<String> value) Future<bool>
remove(String key) Future<bool>
removeAll(List<String> keys) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance StorageUtil
no setter

Static Methods

init({required StorageConfig config}) Future<void>